diff --git a/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py b/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py
index f4455052..15fae06f 100644
--- a/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py
@@ -32,6 +32,10 @@ class TablespaceModule(CollectionNodeModule):
     NODE_TYPE = 'tablespace'
     COLLECTION_LABEL = gettext("Tablespaces")
 
+    def __init__(self, import_name, **kwargs):
+        super(TablespaceModule, self).__init__(import_name, **kwargs)
+        self.min_gpdbver = 90000
+
     def get_nodes(self, gid, sid):
         """
         Generate the collection node
diff --git a/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_backend_supported.py b/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_backend_supported.py
new file mode 100644
index 00000000..3aa43e27
--- /dev/null
+++ b/web/pgadmin/browser/server_groups/servers/tablespaces/tests/test_backend_supported.py
@@ -0,0 +1,46 @@
+##########################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2018, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##########################################################################
+
+from mock import MagicMock
+
+from pgadmin.browser.server_groups.servers.tablespaces import TablespaceModule
+from pgadmin.utils.route import BaseTestGenerator
+
+
+class BackendSupportedTestCase(BaseTestGenerator):
+    """This class will add tablespace node under server"""
+    scenarios = [
+        ('When server is postgres, it returns true',
+         dict(
+             manager=dict(
+                 sversion=90100,
+                 server_type='pg'
+             ),
+             expected_result=True
+         )),
+        ('When server is GreenPlum 5.0, it returns false',
+         dict(
+             manager=dict(
+                 sversion=80323,
+                 server_type='gpdb'
+             ),
+             expected_result=False
+         ))
+    ]
+    class LocalManager:
+        def __init__(self, properties):
+            self.sversion = properties['sversion']
+            self.sversion = properties['sversion']
+
+    def runTest(self):
+        module = TablespaceModule('name')
+        manager = MagicMock()
+        manager.sversion = self.manager['sversion']
+        manager.server_type = self.manager['server_type']
+        self.assertEquals(self.expected_result, module.BackendSupported(manager))
diff --git a/web/pgadmin/feature_tests/keyboard_shortcut_test.py b/web/pgadmin/feature_tests/keyboard_shortcut_test.py
index 8a1f0433..b83457cf 100644
--- a/web/pgadmin/feature_tests/keyboard_shortcut_test.py
+++ b/web/pgadmin/feature_tests/keyboard_shortcut_test.py
@@ -7,9 +7,10 @@
 #
 ##########################################################################
 
-import os
-import json
+from __future__ import print_function
 import time
+import sys
+
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.common.by import By
@@ -64,6 +65,8 @@ class KeyboardShortcutFeatureTest(BaseFeatureTest):
                 Keys.ALT
             ).perform()
 
+            print("Executing shortcut: " + self.new_shortcuts[s]['locator'] + "...", file=sys.stderr, end="")
+
             self.wait.until(
                 EC.presence_of_element_located(
                     (By.XPATH, "//li[contains(@id, " +
@@ -76,6 +79,8 @@ class KeyboardShortcutFeatureTest(BaseFeatureTest):
 
             assert is_open is True, "Keyboard shortcut change is unsuccessful."
 
+            print("OK", file=sys.stderr)
+
     def _update_preferences(self):
         self.page.find_by_id("mnu_file").click()
         self.page.find_by_id("mnu_preferences").click()
